@@ -2,11 +2,9 @@ package constants
 
 import (
 	"fmt"
-
-	"github.com/turbot/steampipe/pkg/schema"
 )
 
-// dbClient constants
+// Client constants
 const (
 	// MaxParallelClientInits is the number of clients to initialize in parallel
 	// if we start initializing all clients together, it leads to bad performance on all
@@ -32,7 +30,7 @@ const (
 // constants for installing db and fdw images
 const (
 	DatabaseVersion = "14.2.0"
-	FdwVersion      = "1.6.3"
+	FdwVersion      = "1.7.0"
 
 	// PostgresImageRef is the OCI Image ref for the database binaries
 	PostgresImageRef    = "us-docker.pkg.dev/steampipe/steampipe/db:14.2.0"
@@ -44,45 +42,56 @@ const (
 
 // schema names
 const (
-	// FunctionSchema is the schema container for all steampipe helper functions
-	FunctionSchema = "internal"
 
-	// CommandSchema is the schema which is used to send commands to the FDW
-	CommandSchema = "steampipe_command"
+	// legacy schema names
+	// these are schema names which were used previously
+	// but are not relevant anymore and need to be dropped
+	LegacyInternalSchema = "internal"
+	LegacyCommandSchema  = "steampipe_command"
 
-	CommandTableCache                = "cache"
-	CommandTableCacheOperationColumn = "operation"
-	CommandCacheOn                   = "cache_on"
-	CommandCacheOff                  = "cache_off"
-	CommandCacheClear                = "cache_clear"
+	// InternalSchema is the schema container for all steampipe helper functions, and connection state table
+	// also used to send commands to the FDW
+	InternalSchema = "steampipe_internal"
 
-	CommandTableScanMetadata = "scan_metadata"
+	// ConnectionStateTable is the table used to store steampipe connection state
+	ConnectionStateTable             = "steampipe_connection_state"
+	ConnectionStatePending           = "pending"
+	ConnectionStatePendingIncomplete = "incomplete"
+	ConnectionStateReady             = "ready"
+	ConnectionStateUpdating          = "updating"
+	ConnectionStateDeleting          = "deleting"
+	ConnectionStateDisabled          = "disabled"
+	ConnectionStateError             = "error"
+
+	// foreign tables in internal schema
+	ForeignTableScanMetadata              = "steampipe_scan_metadata"
+	ForeignTableSettings                  = "steampipe_settings"
+	ForeignTableSettingsKeyColumn         = "name"
+	ForeignTableSettingsValueColumn       = "value"
+	ForeignTableSettingsCacheKey          = "cache"
+	ForeignTableSettingsCacheTtlKey       = "cache_ttl"
+	ForeignTableSettingsCacheClearTimeKey = "cache_clear_time"
+
+	FunctionCacheSet    = "meta_cache"
+	FunctionCacheSetTtl = "meta_cache_ttl"
 )
 
-// Functions :: a list of SQLFunc objects that are installed in the db 'internal' schema startup
-var Functions = []schema.SQLFunc{
-	{
-		Name:     "glob",
-		Params:   map[string]string{"input_glob": "text"},
-		Returns:  "text",
-		Language: "plpgsql",
-		Body: `
-declare
-	output_pattern text;
-begin
-	output_pattern = replace(input_glob, '*', '%');
-	output_pattern = replace(output_pattern, '?', '_');
-	return output_pattern;
-end;
-`,
-	},
+// ConnectionStates is a handy array of all states
+var ConnectionStates = []string{
+	ConnectionStateTable,
+	ConnectionStatePending,
+	ConnectionStateReady,
+	ConnectionStateUpdating,
+	ConnectionStateDeleting,
+	ConnectionStateError,
 }
 
 var ReservedConnectionNames = []string{
 	"public",
-	FunctionSchema,
 }
 
+const ReservedConnectionNamePrefix = "steampipe_"
+
 // introspection table names
 const (
 	IntrospectionTableQuery              = "steampipe_query"
