@@ -54,16 +54,33 @@ func (c *InteractiveClient) handleInitResult(ctx context.Context, initResult *db
 		initResult.DisplayMessages()
 		// show the prompt again
 		c.hidePrompt = false
+
 		// We need to render the prompt here to make sure that it comes back
-		// after the messages have been displayed
-		c.interactivePrompt.Render()
+		// after the messages have been displayed (only if there's no execution)
+		//
+		// We check for query execution by TRYING to acquire the same lock that
+		// execution locks on
+		//
+		// If we can acquire a lock, that means that there's no
+		// query execution underway - and it is safe to render the prompt
+		//
+		// otherwise, that query execution is waiting for this init to finish
+		// and as such will be out of the prompt - in which case, we shouldn't
+		// re-render the prompt
+		//
+		// the prompt will be re-rendered when the query execution finished
+		if c.executionLock.TryLock() {
+			c.interactivePrompt.Render()
+			// release the lock
+			c.executionLock.Unlock()
+		}
 	}
 
 	// initialise autocomplete suggestions
-	c.initialiseSuggestions()
+	c.initialiseSuggestions(ctx)
 	// tell the workspace to reset the prompt after displaying async filewatcher messages
 	c.initData.Workspace.SetOnFileWatcherEventMessages(func() {
-		c.initialiseQuerySuggestions()
+		c.initialiseSuggestions(ctx)
 		c.interactivePrompt.Render()
 	})
 
@@ -84,14 +101,19 @@ func (c *InteractiveClient) readInitDataStream(ctx context.Context) {
 	if c.initData.Result.Error != nil {
 		return
 	}
+	statushooks.SetStatus(ctx, "Completing initialization…")
+	//  fetch the schema
+	// TODO make this async https://github.com/turbot/steampipe/issues/3400
+	// NOTE: we would like to do this asyncronously, but we are currently limited to a single Db conneciton in our
+	// as the client cache settings are set per connection so we rely on only haveing a single connection
+	// This means that the schema load would block other queries anyway so there is no benefit right not in making asyncronous
 
-	// asyncronously fetch the schema
 	if err := c.loadSchema(); err != nil {
 		c.initData.Result.Error = err
 		return
 	}
 
-	log.Printf("[TRACE] readInitDataStream - data has arrived")
+	log.Printf("[TRACE] SetupWatcher")
 
 	// start the workspace file watcher
 	if viper.GetBool(constants.ArgWatch) {
@@ -101,6 +123,8 @@ func (c *InteractiveClient) readInitDataStream(ctx context.Context) {
 		}
 	}
 
+	log.Printf("[TRACE] Start notifications listener")
+
 	// create a cancellation context used to cancel the listen thread when we exit
 	listenCtx, cancel := context.WithCancel(ctx)
 	go c.listenToPgNotifications(listenCtx)
